This project aim to facilitate the migration from other ERP to Odoo with EMC application:

 - Add new field to SubscriptionRequest to save the migrated cooperator number.

Please don't hesitate to suggest one of your modules to this project.
